@@ -83,7 +83,6 @@ case "La tipologia è sbagliata":  		$messaggio = "La tipologia és errònia"; b
 case "è":  					$messaggio = "és"; break;
 case "pien":  					$messaggio = "ple"; break;
 case "Non c'è più disponibilità nel periodo richiesto":	$messaggio = "No hi ha disponibilitat al període demanat"; break;
-case "C'è ancora disponibilita":		$messaggio = "S'ha trobat disponibilitat"; break;
 case "nel periodo richiesto":			$messaggio = "al període demanat"; break;
 case "nei periodi richiesti":			$messaggio = "als períodes demanats"; break;
 case "per la tipologia":			$messaggio = "per la tipologia"; break;
@@ -267,7 +266,6 @@ case "Data di partenza":  			$messaggio = "Data de sortida"; break;
 case "Tipologia":  				$messaggio = "Tipologia"; break;
 case "default - frame orizzontale":  		$messaggio = "default - frame horitzontal"; break;
 case "Condizioni da accettare nella form":  	$messaggio = "Condicions a acceptar al formulari"; break;
-case "nomi dall'utente delle liste, opzionali nel commento":	$messaggio = "noms de l'usuari de les llistes, opcionals al comentari"; break;
 case "Accetto":  				$messaggio = "Accepto"; break;
 case "larghezza":  				$messaggio = "amplada"; break;
 case "altezza":  				$messaggio = "alçada"; break;
@@ -282,6 +280,7 @@ case "selezionare \"html personalizzato\" nell'aspetto della pagina per modifica
 case "Categoria":  				$messaggio = "Categoria"; break;
 case "Attenzione":  				$messaggio = "Atenció"; break;
 case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto":	$messaggio = "Motivations of assignment rules 1 for conditional availability to consider"; break;
+case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
 case "Email":  					$messaggio = "Email"; break;
 case "Totale":  				$messaggio = "Total"; break;
 case "Documento":  				$messaggio = "Document"; break;
@@ -290,6 +289,11 @@ case "<small>*</small>":  			$messaggio = "<small>*</small>"; break;
 case "documento":  				$messaggio = "document"; break;
 case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "rules 1 for closure are always applied"; break;
 case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "The requested type is closed in this period"; break;
+case "Spostamento orizzontale della posizione":	$messaggio = "Horizontal offset for position"; break;
+case "nomi dall'utente delle liste":		$messaggio = "names from lists user"; break;
+case "aggiunto al commento":  			$messaggio = "added to comment"; break;
+case "aggiunto al campo":  			$messaggio = "added to field"; break;
+case "del cliente":  				$messaggio = "in client data"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -545,10 +549,12 @@ case "var_fr_Data_di_partenza":  		$messaggio = "var_fr_Fecha_de_salida"; break;
 case "var_fr_Tipologia":  			$messaggio = "var_fr_Tipologia"; break;
 case "var_fr_Accetto":  			$messaggio = "var_fr_Acepto"; break;
 
+case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
 case "var_manda_copia_richiesta_email":  	$messaggio = "var_send_copy_of_request_email"; break;
 case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
+case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_custom_form_fields"; break;
 } # fine switch ($messaggio)
 } # fine else if (substr($messaggio,0,4) != "var_")
 
