@@ -381,11 +381,22 @@ case "L'accettazione di questa clausola conferma che gli sviluppatori di questo
 case "Accetto":  				$messaggio = "I Accept"; break;
 case "Declino":  				$messaggio = "I Decline"; break;
 case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
-case "Mostrare le righe con i totali del giorno e del mese?":	$messaggio = "Show rows with daily and monthly totals?"; break;
+case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
+case "giornaliero":  				$messaggio = "daily"; break;
+case "mensile":  				$messaggio = "montly"; break;
+case "tabella":  				$messaggio = "table"; break;
 case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
-case "Cancella le carte di credito di prenotazioni passate":	$messaggio = "Delete credit cards from past reservations"; break;
-case "Si è sicuri di voler cancellare tutte le carte di credito non utilizzate in prenotazioni future o in prenotazioni non ancora pagate?":	$messaggio = "Are you sure you want to delete all credit cards not used in future reservations or in unpaid reservations?"; break;
-case "Carte di credito cancellate":  		$messaggio = "Credit cards deleted"; break;
+case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
+case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
+case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
+case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
+case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
+case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
+case "alfabetico":  				$messaggio = "alphabetically"; break;
+case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
+case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
+case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
+case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
