@@ -47,7 +47,6 @@ case "Possibilità di confermare la prenotazione":	$messaggio = "Possibilitat de
 case "Possibilità di inserire uno sconto":  	$messaggio = "Possibilitat d'inserir un descompte"; break;
 case "Possibilità di inserire la caparra e le commissioni":  	$messaggio = "Possibilitat d'inserir arres i comissions"; break;
 case "Possibilità di inserire dei costi aggiuntivi":	$messaggio = "Possibilitat d'inserir suplements"; break;
-case "Possibilità di inserire un commento":  	$messaggio = "Possibilitat d'inserir un comentari"; break;
 case "Possibilità di inserire il numero di persone":	$messaggio = "Possibilitat d'inserir el número de persones"; break;
 case "Possibilità di inserire prenotazioni anche in periodi già iniziati":	$messaggio = "Possibilitat d'inserir reserves també a períodes ja començats"; break;
 case "Prenotazioni che possono essere <i>modificate</i>":	$messaggio = "Reserves que pueden ésser <i>modificades</i>"; break;
@@ -313,8 +312,6 @@ case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inser
 case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
 case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>extra costs</b> when inserts new reservations in"; break;
 case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>extra costs</b> when inserts new reservations in"; break;
-case "non potrà inserire dei <b>commenti</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>comments</b> when inserts new reservations in"; break;
-case "potrà inserire dei <b>commenti</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>comments</b> when inserts new reservations in"; break;
 case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
 case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
 case "potrà <b>cancellare</b> solo le prenotazioni non iniziate nel":	$messaggio = "will be able to <b>delete</b> only not begun reservations in"; break;
@@ -332,6 +329,21 @@ case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed
 case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Possibility to delete and overwrite saved documents"; break;
 case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will be able to <b>delete and overwrite documents</b> saved in"; break;
 case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will not be able to <b>delete and overwrite documents</b> saved in"; break;
+case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
+case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
+case "Possibilità di vedere il commento":  	$messaggio = "Possibility to view the comment"; break;
+case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Possibility to view and modify custom comments"; break;
+case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>comment</b> when inserts new reservations in"; break;
+case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>comment</b> when inserts new reservations in"; break;
+case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>custom comments</b> when inserts new reservations in"; break;
+case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>custom comments</b> when inserts new reservations in"; break;
+case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to view the <b>comment</b> of reservations in"; break;
+case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to view the <b>comment</b> of reservations in"; break;
+case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will not be able to view and modify <b>custom comments</b> of reservations in"; break;
+case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will be able to view and modify <b>custom comments</b> of reservations in"; break;
+case "Creazione e modifica delle interconnessioni":	$messaggio = "Create and modify interconnections"; break;
+case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "will be able to create and modify <b>interconnections</b>"; break;
+case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "will not be able to create and modify <b>interconnections</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
