@@ -341,7 +341,7 @@ case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "You will make t
 case "Cliente":  				$messaggio = "Client"; break;
 case "cliente":  				$messaggio = "client"; break;
 case "clienti":  				$messaggio = "clients"; break;
-case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro":	$messaggio = "credit cards</b></div> from clients without reservations in the future"; break;
+case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
 case "documento":  				$messaggio = "document"; break;
 case "più di":  				$messaggio = "more than"; break;
 case "prezzi importati":  			$messaggio = "prices imported"; break;
@@ -354,6 +354,9 @@ case "password errata":  			$messaggio = "wrong password"; break;
 case "Creare":  				$messaggio = "Create"; break;
 case "persona":  				$messaggio = "person"; break;
 case "chiusa":  				$messaggio = "closed"; break;
+case "presenti in data":  			$messaggio = "present on"; break;
+case "comprese partenze":  			$messaggio = "including departures"; break;
+case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
